pub struct DeviceAuthorizationResponse {
pub device_code: String,
pub user_code: String,
pub verification_uri: Option<Uri>,
pub verification_url: Option<Uri>,
pub verification_uri_complete: Option<Uri>,
pub expires_in: i64,
pub interval: Option<i64>,
}Expand description
Fields
device_code: Stringdevice verification code
user_code: Stringend user verification code
verification_uri: Option<Uri>end user verification uri on the authorization server
verification_url: Option<Uri>Google use verification_“url”
verification_uri_complete: Option<Uri>a verification uri that includes user_code which is designed for non-textual transmission.
expires_in: i64the lifetime in seconds of the device_code and user_code
interval: Option<i64>the minimum amount of time in seconds that the client should wait between polling requests to the token endpoint if no value is provided, clients must use 5 as the default
Implementations
sourceimpl DeviceAuthorizationResponse
impl DeviceAuthorizationResponse
pub fn verification_uri(&self) -> &Uri